
Authors
=======

* Ionel Cristian Mărieș - http://blog.ionelmc.ro
* Areski Belaid - http://www.areskibelaid.com/
* ??? - https://github.com/artscoop
* Rick van Hattem - http://wol.ph/
* Benjamin Wohlwend - https://github.com/piquadrat
* Trbs - https://github.com/trbs

